# APIKeysRolesEnum


## Enum

* `DEFAULT_MINUS_RULE_MINUS_ADMIN` (value: `'DEFAULT-RULE-ADMIN'`)

* `TASK_MINUS_ADMIN` (value: `'TASK-ADMIN'`)

* `VALIDATION_MINUS_USER` (value: `'VALIDATION-USER'`)

* `ORG_MINUS_AUDITOR` (value: `'ORG-AUDITOR'`)

* `ORG_MINUS_ADMIN` (value: `'ORG-ADMIN'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


